from ._focal_loss import binary_focal_loss, BinaryFocalLoss

# Package information
__package__ = 'focal-loss'
__version__ = '0.0.1'
__author__ = 'Artem Mavrin'
__author_email__ = 'artemvmavrin@gmail.com'
__description__ = 'TensorFlow implementation of focal loss.'
__url__ = 'https://github.com/artemmavrin/focal-loss'
__copyright__ = 'Copyright 2019 Artem Mavrin'
__license__ = 'Apache 2.0'

__doc__ = __description__
